@@ -19,12 +19,10 @@
  */
 
 #include <gtkmm/messagedialog.h>
-#include <string>
-#include "global.hh"
 
-void message_error(std::string str) {
+void message_error(Glib::ustring str) {
 	Gtk::MessageDialog dialog(str, true, Gtk::MESSAGE_WARNING);
 	//dialog.set_secondary_text(str);
-	dialog.set_title("Error");
+	dialog.set_title("Error message");
 	dialog.run();
 }
